@@ -115,11 +115,18 @@ public:
   template<typename TRANSACTOR> 
   void Perform(const TRANSACTOR &T, int Attempts=3);			//[t4]
 
+  // TODO: Define a default Noticer (mainly to help out Windows users)
   /// Set handler for postgresql errors or warning messages.
-  /** Return value is the previous handler.  Must not be NULL.
-   * @param N the new message handler.
+  /** Return value is the previous handler.  Ownership of any previously set 
+   * Noticer is also passed to the caller, so unless it is stored in another 
+   * auto_ptr, it will be deleted from the caller's context.  
+   * This may be important when running under Windows, where a DLL cannot free 
+   * memory allocated by the main program.
+   * If a Noticer is set when the ConnectionItf is destructed, it will also be
+   * deleted.
+   * @param N the new message handler; must not be null or equal to the old one
    */
-  std::auto_ptr<Noticer> SetNoticer(std::auto_ptr<Noticer> N);		//[t14]
+  PGSTD::auto_ptr<Noticer> SetNoticer(PGSTD::auto_ptr<Noticer> N);	//[t14]
   Noticer *GetNoticer() const throw () { return m_Noticer.get(); }	//[]
 
   /// Invoke notice processor function.  The message should end in newline.
@@ -191,6 +198,15 @@ public:
    */
   void Deactivate() const;						//[]
 
+  /// Set client-side character encoding
+  /** Search the PostgreSQL documentation for "multibyte" or "character set
+   * encodings" to find out more about the available encodings, how to extend
+   * them, and how to use them.  Not all server-side encodings are compatible 
+   * with all client-side encodings or vice versa.
+   * @parm Encoding name of the character set encoding to use
+   */
+  void SetClientEncoding(const char Encoding[]);			//[]
+
 protected:
   /// To be used by implementation classes: reall connecto to database
   void Connect() const;
@@ -201,12 +217,13 @@ private:
   int Status() const { return PQstatus(m_Conn); }
   const char *ErrMsg() const;
   void Reset(const char OnReconnect[]=0);
+  void close() throw ();
 
   PGSTD::string m_ConnInfo;	/// Connection string
   mutable PGconn *m_Conn;	/// Connection handle
   Unique<TransactionItf> m_Trans;/// Active transaction on connection, if any
 
-  std::auto_ptr<Noticer> m_Noticer;	/// User-defined notice processor
+  PGSTD::auto_ptr<Noticer> m_Noticer;	/// User-defined notice processor
   FILE *m_Trace;		/// File to trace to, if any
 
   typedef PGSTD::multimap<PGSTD::string, pqxx::Trigger *> TriggerList;
@@ -298,5 +315,11 @@ inline void pqxx::ConnectionItf::Perform(const TRANSACTOR &T,
 }
 
 
+// Put this here so on Windows, any Noticer will be deleted in caller's context
+inline pqxx::ConnectionItf::~ConnectionItf()
+{
+  close();
+}
+
 #endif
 
